@@ -39,7 +39,6 @@ def run_main():
     main(*args, **kwargs)
 
 def main(*args, **kwargs):
-
     vars = Globals()
     # Check for arguements
     if not args and not kwargs and hasWx:        
@@ -48,6 +47,7 @@ def main(*args, **kwargs):
         form.update_dataset_list()
 
         form.Show()
+        form.Maximize(True)
         app.MainLoop()
 
         # vars.action not defined, quit...
@@ -73,7 +73,6 @@ def main(*args, **kwargs):
         show_help()
 
     else:
-
         # Show help if needed
         if "help" in kwargs or "-help" in kwargs:
             show_help()
@@ -82,7 +81,8 @@ def main(*args, **kwargs):
         # Check for strange flags
         known_flags = set(["tn5", "help", "himar1", "protocol", "primer", "reads1",
                            "reads2", "bwa", "ref", "maxreads", "output", "mismatches", "flags",
-                           "barseq_catalog_in", "barseq_catalog_out"])
+                           "barseq_catalog_in", "barseq_catalog_out",
+                           "window-size", "bwa-alg", "replicon-ids","primer-start-window"])
         unknown_flags = set(kwargs.keys()) - known_flags
         if unknown_flags:
             print "error: unrecognized flags:", ", ".join(unknown_flags)
