@@ -20,7 +20,9 @@ import utest
 import normalize
 import pathway_enrichment #08/22/2018 by Ivan
 import anova
+import zinb
 import tnseq_stats
+import winsorize
 
 methods = {}
 methods["example"] = example.ExampleAnalysis()
@@ -34,12 +36,14 @@ methods["rankproduct"] = rankproduct.RankProductAnalysis()
 methods["utest"] = utest.UTestAnalysis()
 methods["GI"] = gi.GIAnalysis()
 methods["anova"] = anova.AnovaAnalysis()
+methods["zinb"] = zinb.ZinbAnalysis()
 #methods["mcce"] = mcce.MCCEAnalysis()
 #methods["mcce2"] = mcce2.MCCE2Analysis()
 #methods["motifhmm"] = motifhmm.MotifHMMAnalysis()
 methods["normalize"] = normalize.Normalize()
 methods["pathway_enrichment"]=pathway_enrichment.GSEAAnalysis()
 methods["tnseq_stats"]=tnseq_stats.TnseqStats()
+methods["winsorize"] = winsorize.Winsorize()
 
 # EXPORT METHODS
 import norm
