@@ -54,7 +54,7 @@ class Normalize(base.TransitAnalysis):
 class NormalizeFile(base.TransitFile):
 
     def __init__(self):
-        base.TransitFile.__init__(self, "#CombinedWig", columns) 
+        base.TransitFile.__init__(self, "#CombinedWig", columns)
 
     def getHeader(self, path):
         text = """This is file contains mean counts for each gene. Nzmean is mean accross non-zero sites."""
@@ -72,9 +72,9 @@ class NormalizeGUI(base.AnalysisGUI):
 
 
 class NormalizeMethod(base.SingleConditionMethod):
-    """   
+    """
     Norm
- 
+
     """
     def __init__(self,infile,outfile,normalization):
                 ctrldata=[infile]
@@ -91,17 +91,20 @@ class NormalizeMethod(base.SingleConditionMethod):
 
 
     @classmethod
-    def fromargs(self, rawargs): 
+    def fromargs(self, rawargs):
         (args, kwargs) = transit_tools.cleanargs(rawargs)
 
-        if len(args) < 2:
+        isCombinedWig = kwargs.has_key('c')
+        if (not isCombinedWig and len(args) < 2) or (isCombinedWig and len(args) < 1):
             raise base.InvalidArgumentException("Must provide all necessary arguments")
-            
-
-        self.infile = args[0] # only 1 input wig file
-        self.outfile = args[1] # if no arg give, could print to screen
+        if isCombinedWig:
+            self.infile = kwargs.get("c") # only 1 input wig file
+            self.outfile = args[0] # if no arg give, could print to screen
+        else:
+            self.infile = args[0] # only 1 input wig file
+            self.outfile = args[1] # if no arg give, could print to screen
         self.normalization = kwargs.get("n", "TTR") # check if it is a legal method name
-        self.combined_wig = kwargs.get("c",False)
+        self.combined_wig = isCombinedWig
 
         return self(self.infile,self.outfile,self.normalization)
 
@@ -135,17 +138,20 @@ class NormalizeMethod(base.SingleConditionMethod):
         file.close()
 
         self.finish()
-        self.transit_message("Finished Normalization") 
+        self.transit_message("Finished Normalization")
 
     @classmethod
     def usage_string(self):
         return """
-python %s normalize <input.wig> <output.wig> [-c] [-n TTR|betageom]
-    
+python %s normalize <input.wig> <output.wig> [-n TTR|betageom]
+---
+OR
+---
+python %s normalize -c <input combined_wig> <output.wig> [-n TTR|betageom]
+
         Optional Arguments:
-        -c              := the input file is a combined_wig file
         -n <string>     :=  Normalization method. Default: -n TTR
-        """ % (sys.argv[0])
+        """ % (sys.argv[0], sys.argv[0])
 
 
 
