@@ -94,7 +94,7 @@ class ResamplingFile(base.TransitFile):
                 print "Error Displaying File. Histogram image does not exist."
 
 
-        
+
 
 ############# GUI ##################
 
@@ -115,13 +115,13 @@ class ResamplingGUI(base.AnalysisGUI):
         resamplingTopSizer2 = wx.BoxSizer( wx.HORIZONTAL )
 
         resamplingLabelSizer = wx.BoxSizer( wx.VERTICAL )
-        
+
         mainSizer1 = wx.BoxSizer( wx.VERTICAL )
 
         #(, , Sizer) = self.defineChoiceBox(resamplingPanel, u"", u"", "")
         #mainSizer1.Add(Sizer, 1, wx.ALIGN_CENTER_HORIZONTAL|wx.EXPAND, 5 )
 
-        # Samples 
+        # Samples
         (resamplingSampleLabel, self.wxobj.resamplingSampleText, sampleSizer) = self.defineTextBox(resamplingPanel, u"Samples:", u"10000", "Number of samples to take when estimating the resampling histogram. More samples give more accurate estimates of the p-values at the cost of computation time.")
         mainSizer1.Add(sampleSizer, 1, wx.ALIGN_CENTER_HORIZONTAL|wx.EXPAND, 5 )
 
@@ -129,10 +129,10 @@ class ResamplingGUI(base.AnalysisGUI):
         (resamplingPseudocountLabel, self.wxobj.resamplingPseudocountText, pseudoSizer) = self.defineTextBox(resamplingPanel, u"Pseudocount:", u"0.0", "Adds pseudo-counts to the each data-point. Useful to dampen the effects of small counts which may lead to deceptively high log-FC.")
         mainSizer1.Add(pseudoSizer, 1, wx.ALIGN_CENTER_HORIZONTAL|wx.EXPAND, 5 )
 
-        # Norm 
+        # Norm
         resamplingNormChoiceChoices = [ u"TTR", u"nzmean", u"totreads", u'zinfnb', u'quantile', u"betageom", u"nonorm" ]
         (resamplingNormLabel, self.wxobj.resamplingNormChoice, normSizer) = self.defineChoiceBox(resamplingPanel, u"Normalization: ", resamplingNormChoiceChoices, "Choice of normalization method. The default choice, 'TTR', normalizes datasets to have the same expected count (while not being sensative to outliers). Read documentation for a description other methods. ")
-        mainSizer1.Add(normSizer, 1, wx.ALIGN_CENTER_HORIZONTAL|wx.EXPAND, 5 ) 
+        mainSizer1.Add(normSizer, 1, wx.ALIGN_CENTER_HORIZONTAL|wx.EXPAND, 5 )
 
 
 
@@ -159,24 +159,24 @@ class ResamplingGUI(base.AnalysisGUI):
         # Histogram Check
         (self.wxobj.resamplingHistogramCheckBox, histSizer) = self.defineCheckBox(resamplingPanel, labelText="Generate Resampling Histograms", widgetCheck=False, widgetSize=(-1,-1), tooltipText="Creates .png images with the resampling histogram for each of the ORFs. Histogram images are created in a folder with the same name as the output file.")
         resamplingSizer.Add(histSizer, 0, wx.EXPAND, 5 )
-        
+
 
         # Zeros Check
-        (self.wxobj.resamplingZeroCheckBox, zeroSizer) = self.defineCheckBox(resamplingPanel, labelText="Include sites with all zeros", widgetCheck=True, widgetSize=(-1,-1), tooltipText="Includes sites that are empty (zero) accross all datasets. Unchecking this may be useful for tn5 datasets, where all nucleotides are possible insertion sites and will have a large number of empty sites (significantly slowing down computation and affecting estimates).")
+        (self.wxobj.resamplingZeroCheckBox, zeroSizer) = self.defineCheckBox(resamplingPanel, labelText="Include sites with all zeros", widgetCheck=True, widgetSize=(-1,-1), tooltipText="Includes sites that are empty (zero) across all datasets. Unchecking this may be useful for tn5 datasets, where all nucleotides are possible insertion sites and will have a large number of empty sites (significantly slowing down computation and affecting estimates).")
         resamplingSizer.Add(zeroSizer, 0, wx.EXPAND, 5 )
 
 
         resamplingButton = wx.Button( resamplingPanel, wx.ID_ANY, u"Run resampling", wx.DefaultPosition, wx.DefaultSize, 0 )
         resamplingSizer.Add( resamplingButton, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL, 5 )
 
- 
+
         resamplingPanel.SetSizer( resamplingSizer )
         resamplingPanel.Layout()
         resamplingSizer.Fit( resamplingPanel )
 
         #Connect events
         resamplingButton.Bind( wx.EVT_BUTTON, self.wxobj.RunMethod )
-        self.wxobj.resamplingLoessPrev.Bind(wx.EVT_BUTTON, self.wxobj.LoessPrevFunc)        
+        self.wxobj.resamplingLoessPrev.Bind(wx.EVT_BUTTON, self.wxobj.LoessPrevFunc)
 
         self.panel = resamplingPanel
 
@@ -193,9 +193,9 @@ class ResamplingGUI(base.AnalysisGUI):
 ########## CLASS #######################
 
 class ResamplingMethod(base.DualConditionMethod):
-    """   
+    """
     resampling
- 
+
     """
     def __init__(self,
                 ctrldata,
@@ -212,31 +212,43 @@ class ResamplingMethod(base.DualConditionMethod):
                 LOESS=False,
                 ignoreCodon=True,
                 NTerminus=0.0,
-                CTerminus=0.0, 
+                CTerminus=0.0,
                 ctrl_lib_str="",
-                exp_lib_str="", # should add Z
-                wxobj=None):
+                exp_lib_str="",
+                wxobj=None, Z = False, diffStrains = False, annotation_path_exp = "", combinedWigParams = None):
 
         base.DualConditionMethod.__init__(self, short_name, long_name, short_desc, long_desc, ctrldata, expdata, annotation_path, output_file, normalization=normalization, replicates=replicates, LOESS=LOESS, NTerminus=NTerminus, CTerminus=CTerminus, wxobj=wxobj)
 
-        self.Z = False
+        self.Z = Z
         self.samples = samples
         self.adaptive = adaptive
         self.doHistogram = doHistogram
         self.includeZeros = includeZeros
         self.pseudocount = pseudocount
         self.ctrl_lib_str = ctrl_lib_str
-        self.exp_lib_str = exp_lib_str 
-
+        self.exp_lib_str = exp_lib_str
+        self.diffStrains = diffStrains
+        self.annotation_path_exp = annotation_path_exp if diffStrains else annotation_path
+        self.combinedWigParams = combinedWigParams
 
     @classmethod
     def fromGUI(self, wxobj):
         """ """
         #Get Annotation file
-        annotationPath = wxobj.annotation
+        annot_paths = wxobj.annotation.split(",")
+        annotationPath = annot_paths[0]
+        diffStrains = False
+        annotationPathExp = ""
+        if len(annot_paths) == 2:
+            annotationPathExp = annot_paths[1]
+            diffStrains = True
+
         if not transit_tools.validate_annotation(annotationPath):
             return None
 
+        if annotationPathExp and not transit_tools.validate_annotation(annotationPathExp):
+            return None
+
         #Get selected files
         ctrldata = wxobj.ctrlSelected()
         expdata = wxobj.expSelected()
@@ -272,7 +284,7 @@ class ResamplingMethod(base.DualConditionMethod):
         if adaptive: defaultFileName+= "_adaptive"
         if includeZeros: defaultFileName+= "_iz"
         defaultFileName+=".dat"
-    
+
         defaultDir = os.getcwd()
         output_path = wxobj.SaveFile(defaultDir, defaultFileName)
         if not output_path: return None
@@ -293,19 +305,50 @@ class ResamplingMethod(base.DualConditionMethod):
                 LOESS,
                 ignoreCodon,
                 NTerminus,
-                CTerminus, 
+                CTerminus,
                 ctrl_lib_str,
-                exp_lib_str, wxobj)
+                exp_lib_str, wxobj, Z = False, diffStrains = diffStrains, annotation_path_exp = annotationPathExp)
 
     @classmethod
     def fromargs(self, rawargs):
 
         (args, kwargs) = transit_tools.cleanargs(rawargs)
 
-        ctrldata = args[0].split(",")
-        expdata = args[1].split(",")
-        annotationPath = args[2]
-        output_path = args[3]
+        isCombinedWig = True if kwargs.get('c', False) else False
+        combinedWigParams = None
+        if isCombinedWig:
+            if (len(args) != 5):
+                print("Error: Incorrect number of args. See usage")
+                print(self.usage_string())
+                sys.exit(0)
+            combinedWigParams = {
+                "combined_wig": kwargs.get('c'),
+                "samples_metadata": args[0],
+                "conditions": [args[1].lower(), args[2].lower()]
+            }
+            annot_paths = args[3].split(",")
+            ctrldata = ""
+            expdata = ""
+            output_path = args[4]
+        else:
+            if (len(args) != 4):
+                print("Error: Incorrect number of args. See usage")
+                print(self.usage_string())
+                sys.exit(0)
+            ctrldata = args[0].split(",")
+            expdata = args[1].split(",")
+            annot_paths = args[2].split(",")
+            output_path = args[3]
+        annotationPath = annot_paths[0]
+        diffStrains = False
+        annotationPathExp = ""
+        if len(annot_paths) == 2:
+            annotationPathExp = annot_paths[1]
+            diffStrains = True
+        if (diffStrains and isCombinedWig):
+            print("Error: Cannot have combined wig and different annotation files.")
+            sys.exit(0)
+
         output_file = open(output_path, "w")
 
         normalization = kwargs.get("n", "TTR")
@@ -317,11 +360,11 @@ class ResamplingMethod(base.DualConditionMethod):
         includeZeros = not excludeZeros
         pseudocount = float(kwargs.get("pc", 0.00))
 
-        if "Z" in kwargs: self.Z = True    
-        
+        Z = True if "Z" in kwargs else False
+
         LOESS = kwargs.get("l", False)
         ignoreCodon = True
-    
+
         NTerminus = float(kwargs.get("iN", 0.00))
         CTerminus = float(kwargs.get("iC", 0.00))
         ctrl_lib_str = kwargs.get("-ctrl_lib", "")
@@ -343,7 +386,45 @@ class ResamplingMethod(base.DualConditionMethod):
                 NTerminus,
                 CTerminus,
                 ctrl_lib_str,
-                exp_lib_str) # should add Z
+                exp_lib_str, Z = Z, diffStrains = diffStrains, annotation_path_exp = annotationPathExp, combinedWigParams = combinedWigParams)
+
+    def preprocess_data(self, position, data):
+        (K,N) = data.shape
+
+        if self.normalization != "nonorm":
+            self.transit_message("Normalizing using: %s" % self.normalization)
+            (data, factors) = norm_tools.normalize_data(data, self.normalization, self.ctrldata+self.expdata, self.annotation_path)
+
+        if self.LOESS:
+            self.transit_message("Performing LOESS Correction")
+            for j in range(K):
+                data[j] = stat_tools.loess_correction(position, data[j])
+
+        return data
+
+    def wigs_to_conditions(self, conditionsByFile, filenamesInCombWig):
+        """
+            Returns list of conditions corresponding to given wigfiles.
+            ({FileName: Condition}, [FileName]) -> [Condition]
+            Condition :: [String]
+        """
+        return [conditionsByFile.get(f, None) for f in filenamesInCombWig]
+
+    def filter_wigs_by_conditions(self, data, conditions, included_conditions):
+        """
+            Filters conditions from wig to ctrl, exp conditions only
+            ([[Wigdata]], [ConditionCtrl, ConditionExp]) -> Tuple([[Wigdata]], [Condition])
+        """
+        d_filtered, cond_filtered = [], []
+        if len(included_conditions) != 2:
+            self.transit_error("Only 2 conditions expected", included_conditions)
+            sys.exit(0)
+        for i, c in enumerate(conditions):
+          if (c.lower() in included_conditions):
+            d_filtered.append(data[i])
+            cond_filtered.append(conditions[i])
+
+        return (numpy.array(d_filtered), numpy.array(cond_filtered))
 
     def Run(self):
 
@@ -355,45 +436,52 @@ class ResamplingMethod(base.DualConditionMethod):
             import matplotlib.pyplot as plt
         except:
             print "Error: cannot do histograms"
-            self.doHistogram = False 
-                
+            self.doHistogram = False
+
 
         self.transit_message("Starting resampling Method")
         start_time = time.time()
-       
 
+        histPath = ""
         if self.doHistogram:
             histPath = os.path.join(os.path.dirname(self.output.name), transit_tools.fetch_name(self.output.name)+"_histograms")
             if not os.path.isdir(histPath):
                 os.makedirs(histPath)
-        else:
-            histPath = ""
- 
 
-
-
-        Kctrl = len(self.ctrldata)
-        Kexp = len(self.expdata)
         #Get orf data
         self.transit_message("Getting Data")
-        (data, position) = transit_tools.get_validated_data(self.ctrldata+self.expdata, wxobj=self.wxobj)
+        if self.diffStrains:
+            self.transit_message("Multiple annotation files found")
+            self.transit_message("Mapping ctrl data to {0}, exp data to {1}".format(self.annotation_path, self.annotation_path_exp))
 
-        (K,N) = data.shape
+        if self.combinedWigParams:
+            (position, data, filenamesInCombWig) = tnseq_tools.read_combined_wig(self.combinedWigParams['combined_wig'])
+            conditionsByFile, _, _, _ = tnseq_tools.read_samples_metadata(self.combinedWigParams['samples_metadata'])
+            conditions = self.wigs_to_conditions(conditionsByFile, filenamesInCombWig)
+            data, conditions = self.filter_wigs_by_conditions(data, conditions, self.combinedWigParams['conditions'])
+            data_ctrl = numpy.array([d for i, d in enumerate(data) if conditions[i].lower() == self.combinedWigParams['conditions'][0]])
+            data_exp = numpy.array([d for i, d in enumerate(data) if conditions[i].lower() == self.combinedWigParams['conditions'][1]])
+            position_ctrl, position_exp = position, position
+        else:
+            (data_ctrl, position_ctrl) = transit_tools.get_validated_data(self.ctrldata, wxobj=self.wxobj)
+            (data_exp, position_exp) = transit_tools.get_validated_data(self.expdata, wxobj=self.wxobj)
+        (K_ctrl, N_ctrl) = data_ctrl.shape
+        (K_exp, N_exp) = data_exp.shape
 
+        if not self.diffStrains and (N_ctrl != N_exp):
+            self.transit_error("Error: Ctrl and Exp wig files don't have the same number of sites.")
+            self.transit_error("Make sure all .wig files come from the same strain.")
+            return
+        # (data, position) = transit_tools.get_validated_data(self.ctrldata+self.expdata, wxobj=self.wxobj)
 
-        if self.normalization != "nonorm":
-            self.transit_message("Normalizing using: %s" % self.normalization)
-            (data, factors) = norm_tools.normalize_data(data, self.normalization, self.ctrldata+self.expdata, self.annotation_path)
-
-        if self.LOESS:
-            self.transit_message("Performing LOESS Correction")
-            for j in range(K):
-                data[j] = stat_tools.loess_correction(position, data[j])
-
-
-        G = tnseq_tools.Genes(self.ctrldata + self.expdata, self.annotation_path, ignoreCodon=self.ignoreCodon, nterm=self.NTerminus, cterm=self.CTerminus, data=data, position=position)
+        self.transit_message("Preprocessing Ctrl data...")
+        data_ctrl = self.preprocess_data(position_ctrl, data_ctrl)
 
+        self.transit_message("Preprocessing Exp data...")
+        data_exp = self.preprocess_data(position_exp, data_exp)
 
+        G_ctrl = tnseq_tools.Genes(self.ctrldata, self.annotation_path, ignoreCodon=self.ignoreCodon, nterm=self.NTerminus, cterm=self.CTerminus, data=data_ctrl, position=position_ctrl)
+        G_exp = tnseq_tools.Genes(self.expdata, self.annotation_path_exp, ignoreCodon=self.ignoreCodon, nterm=self.NTerminus, cterm=self.CTerminus, data=data_exp, position=position_exp)
 
         doLibraryResampling = False
         # If library string not empty
@@ -413,34 +501,90 @@ class ResamplingMethod(base.DualConditionMethod):
                 else:
                     transit_tools.transit_error("Error: Library Strings (Ctrl = %s, Exp = %s) do not use the same letters. Make sure every letter / library is represented in both Control and Experimental Conditions. Proceeding with resampling assuming all datasets belong to the same library." % (self.ctrl_lib_str, self.exp_lib_str))
                     self.ctrl_lib_str = ""
-                    self.exp_lib_str = "" 
+                    self.exp_lib_str = ""
 
+        (data, qval) = self.run_resampling(G_ctrl, G_exp, doLibraryResampling, histPath)
+        self.write_output(data, qval, start_time)
 
-        #Resampling
+        self.finish()
+        self.transit_message("Finished resampling Method")
+
+    def write_output(self, data, qval, start_time):
+
+        self.output.write("#Resampling\n")
+        if self.wxobj:
+            members = sorted([attr for attr in dir(self) if not callable(getattr(self,attr)) and not attr.startswith("__")])
+            memberstr = ""
+            for m in members:
+                memberstr += "%s = %s, " % (m, getattr(self, m))
+            self.output.write("#GUI with: norm=%s, samples=%s, pseudocounts=%1.2f, adaptive=%s, histogram=%s, includeZeros=%s, output=%s\n" % (self.normalization, self.samples, self.pseudocount, self.adaptive, self.doHistogram, self.includeZeros, self.output.name.encode('utf-8')))
+        else:
+            self.output.write("#Console: python %s\n" % " ".join(sys.argv))
+        self.output.write("#Control Data: %s\n" % (",".join(self.ctrldata).encode('utf-8')))
+        self.output.write("#Experimental Data: %s\n" % (",".join(self.expdata).encode('utf-8')))
+        self.output.write("#Annotation path: %s %s\n" % (self.annotation_path.encode('utf-8'), self.annotation_path_exp.encode('utf-8') if self.diffStrains else ''))
+        self.output.write("#Time: %s\n" % (time.time() - start_time))
+        #Z = True # include Z-score column in resampling output?
+        global columns # consider redefining columns above (for GUI)
+        if self.Z==True: columns = ["Orf","Name","Desc","Sites","Mean Ctrl","Mean Exp","log2FC", "Sum Ctrl", "Sum Exp", "Delta Mean","p-value","Z-score","Adj. p-value"]
+        self.output.write("#%s\n" % "\t".join(columns))
+
+        for i,row in enumerate(data):
+            (orf, name, desc, n, mean1, mean2, sum1, sum2, test_obs, log2FC, pval_2tail) = row
+            if self.Z==True:
+              p = pval_2tail/2 # convert from 2-sided back to 1-sided
+              if p==0: p = 1e-5 # or 1 level deeper the num of iterations of resampling, which is 1e-4=1/10000, by default
+              if p==1: p = 1-1e-5
+              z = scipy.stats.norm.ppf(p)
+              if log2FC>0: z *= -1
+              self.output.write("%s\t%s\t%s\t%d\t%1.1f\t%1.1f\t%1.2f\t%1.1f\t%1.2f\t%1.1f\t%1.5f\t%0.2f\t%1.5f\n" % (orf, name, desc, n, mean1, mean2, log2FC, sum1, sum2, test_obs, pval_2tail, z, qval[i]))
+            else: self.output.write("%s\t%s\t%s\t%d\t%1.1f\t%1.1f\t%1.2f\t%1.1f\t%1.2f\t%1.1f\t%1.5f\t%1.5f\n" % (orf, name, desc, n, mean1, mean2, log2FC, sum1, sum2, test_obs, pval_2tail, qval[i]))
+        self.output.close()
+
+        self.transit_message("Adding File: %s" % (self.output.name))
+        self.add_file(filetype="Resampling")
+
+    def run_resampling(self, G_ctrl, G_exp = None, doLibraryResampling = False, histPath = ""):
         data = []
-        N = len(G)
+        N = len(G_ctrl)
         count = 0
         self.progress_range(N)
-        for gene in G:
+
+        for gene in G_ctrl:
+            if gene.orf not in G_exp:
+                if self.diffStrains:
+                    continue
+                else:
+                    self.transit_error("Error: Gene in ctrl data not present in exp data")
+                    self.transit_error("Make sure all .wig files come from the same strain.")
+                    return ([], [])
+
+            gene_exp = G_exp[gene.orf]
             count+=1
-            if gene.k == 0 or gene.n == 0:
+
+            if not self.diffStrains and gene.n != gene_exp.n:
+                self.transit_error("Error: No. of TA sites in Exp and Ctrl data are different")
+                self.transit_error("Make sure all .wig files come from the same strain.")
+                return ([], [])
+
+            if (gene.k == 0 and gene_exp.k == 0) or gene.n == 0 or gene_exp.n == 0:
                 (test_obs, mean1, mean2, log2FC, pval_ltail, pval_utail,  pval_2tail, testlist, data1, data2) = (0, 0, 0, 0, 1.00, 1.00, 1.00, [], [0], [0])
             else:
-
                 if not self.includeZeros:
-                    ii = numpy.sum(gene.reads,0) > 0
+                    ii_ctrl = numpy.sum(gene.reads,0) > 0
+                    ii_exp = numpy.sum(gene_exp.reads,0) > 0
                 else:
-                    ii = numpy.ones(gene.n) == 1
-               
+                    ii_ctrl = numpy.ones(gene.n) == 1
+                    ii_exp = numpy.ones(gene_exp.n) == 1
+
+                data1 = gene.reads[:,ii_ctrl].flatten() + self.pseudocount
+                data2 = gene_exp.reads[:,ii_exp].flatten() + self.pseudocount
 
-                data1 = gene.reads[:Kctrl,ii].flatten()+self.pseudocount
-                data2 = gene.reads[Kctrl:,ii].flatten()+self.pseudocount
-               
                 if doLibraryResampling:
                     (test_obs, mean1, mean2, log2FC, pval_ltail, pval_utail,  pval_2tail, testlist) =  stat_tools.resampling(data1, data2, S=self.samples, testFunc=stat_tools.F_mean_diff_dict, permFunc=stat_tools.F_shuffle_dict_libraries, adaptive=self.adaptive, lib_str1=self.ctrl_lib_str, lib_str2=self.exp_lib_str)
                 else:
                     (test_obs, mean1, mean2, log2FC, pval_ltail, pval_utail,  pval_2tail, testlist) =  stat_tools.resampling(data1, data2, S=self.samples, testFunc=stat_tools.F_mean_diff_flat, permFunc=stat_tools.F_shuffle_flat, adaptive=self.adaptive, lib_str1=self.ctrl_lib_str, lib_str2=self.exp_lib_str)
- 
+
 
             if self.doHistogram:
                 import matplotlib.pyplot as plt
@@ -463,71 +607,42 @@ class ResamplingMethod(base.DualConditionMethod):
             sum1 = numpy.sum(data1)
             sum2 = numpy.sum(data2)
             data.append([gene.orf, gene.name, gene.desc, gene.n, mean1, mean2, sum1, sum2, test_obs, log2FC, pval_2tail])
-            
+
             # Update progress
             text = "Running Resampling Method... %5.1f%%" % (100.0*count/N)
             self.progress_update(text, count)
 
 
         #
-        self.transit_message("") # Printing empty line to flush stdout 
+        self.transit_message("") # Printing empty line to flush stdout
         self.transit_message("Performing Benjamini-Hochberg Correction")
-        data.sort() 
+        data.sort()
         qval = stat_tools.BH_fdr_correction([row[-1] for row in data])
-       
-        self.output.write("#Resampling\n")
-        if self.wxobj:
-            members = sorted([attr for attr in dir(self) if not callable(getattr(self,attr)) and not attr.startswith("__")])
-            memberstr = ""
-            for m in members:
-                memberstr += "%s = %s, " % (m, getattr(self, m))
-            self.output.write("#GUI with: norm=%s, samples=%s, pseudocounts=%1.2f, adaptive=%s, histogram=%s, includeZeros=%s, output=%s\n" % (self.normalization, self.samples, self.pseudocount, self.adaptive, self.doHistogram, self.includeZeros, self.output.name.encode('utf-8')))
-        else:
-            self.output.write("#Console: python %s\n" % " ".join(sys.argv))
-        self.output.write("#Control Data: %s\n" % (",".join(self.ctrldata).encode('utf-8'))) 
-        self.output.write("#Experimental Data: %s\n" % (",".join(self.expdata).encode('utf-8'))) 
-        self.output.write("#Annotation path: %s\n" % (self.annotation_path.encode('utf-8')))
-        self.output.write("#Time: %s\n" % (time.time() - start_time))
-        #Z = True # include Z-score column in resampling output? 
-        global columns # consider redefining columns above (for GUI)
-        if self.Z==True: columns = ["Orf","Name","Desc","Sites","Mean Ctrl","Mean Exp","log2FC", "Sum Ctrl", "Sum Exp", "Delta Mean","p-value","Z-score","Adj. p-value"]
-        self.output.write("#%s\n" % "\t".join(columns))
-
-        for i,row in enumerate(data):
-            (orf, name, desc, n, mean1, mean2, sum1, sum2, test_obs, log2FC, pval_2tail) = row
-            if self.Z==True:
-              p = pval_2tail/2 # convert from 2-sided back to 1-sided
-              if p==0: p = 1e-5 # or 1 level deeper the num of iterations of resampling, which is 1e-4=1/10000, by default
-              if p==1: p = 1-1e-5
-              z = scipy.stats.norm.ppf(p)
-              if log2FC>0: z *= -1
-              self.output.write("%s\t%s\t%s\t%d\t%1.1f\t%1.1f\t%1.2f\t%1.1f\t%1.2f\t%1.1f\t%1.5f\t%0.2f\t%1.5f\n" % (orf, name, desc, n, mean1, mean2, log2FC, sum1, sum2, test_obs, pval_2tail, z, qval[i]))
-            else: self.output.write("%s\t%s\t%s\t%d\t%1.1f\t%1.1f\t%1.2f\t%1.1f\t%1.2f\t%1.1f\t%1.5f\t%1.5f\n" % (orf, name, desc, n, mean1, mean2, log2FC, sum1, sum2, test_obs, pval_2tail, qval[i]))
-        self.output.close()
-
-        self.transit_message("Adding File: %s" % (self.output.name))
-        self.add_file(filetype="Resampling")
-        self.finish()
-        self.transit_message("Finished resampling Method") 
-
 
+        return (data, qval)
 
     @classmethod
     def usage_string(self):
-        return """python %s resampling <comma-separated .wig control files> <comma-separated .wig experimental files> <annotation .prot_table or GFF3> <output file> [Optional Arguments]
-    
+        return """
+        python %s resampling <comma-separated .wig control files> <comma-separated .wig experimental files> <annotation .prot_table or GFF3> <output file> [Optional Arguments]
+        ---
+        OR
+        ---
+        python %s resampling -c <combined wig file> <samples_metadata file> <ctrl condition name> <exp condition name> <annotation .prot_table> <output file> [Optional Arguments]
+        NB: The ctrl and exp condition names should match Condition names in samples_metadata file.
+
         Optional Arguments:
         -s <integer>    :=  Number of samples. Default: -s 10000
         -n <string>     :=  Normalization method. Default: -n TTR
         -h              :=  Output histogram of the permutations for each gene. Default: Turned Off.
         -a              :=  Perform adaptive resampling. Default: Turned Off.
-        -ez             :=  Exclude rows with zero accross conditions. Default: Turned off 
+        -ez             :=  Exclude rows with zero across conditions. Default: Turned off
                             (i.e. include rows with zeros).
         -pc             :=  Pseudocounts to be added at each site.
         -l              :=  Perform LOESS Correction; Helps remove possible genomic position bias.
                             Default: Turned Off.
-        -iN <float>     :=  Ignore TAs occuring at given fraction of the N terminus. Default: -iN 0.0
-        -iC <float>     :=  Ignore TAs occuring at given fraction of the C terminus. Default: -iC 0.0
+        -iN <float>     :=  Ignore TAs occuring within given percentage (as integer) of the N terminus. Default: -iN 0
+        -iC <float>     :=  Ignore TAs occuring within given percentage (as integer) of the C terminus. Default: -iC 0
         --ctrl_lib      :=  String of letters representing library of control files in order
                             e.g. 'AABB'. Default empty. Letters used must also be used in --exp_lib
                             If non-empty, resampling will limit permutations to within-libraries.
@@ -536,10 +651,7 @@ class ResamplingMethod(base.DualConditionMethod):
                             e.g. 'ABAB'. Default empty. Letters used must also be used in --ctrl_lib
                             If non-empty, resampling will limit permutations to within-libraries.
 
-        """ % (sys.argv[0])
-
-
-
+        """ % (sys.argv[0], sys.argv[0])
 
 if __name__ == "__main__":
 
@@ -549,7 +661,7 @@ if __name__ == "__main__":
 
     G = ResamplingMethod.fromargs(sys.argv[1:])
 
-    G.console_message("Printing the member variables:")   
+    G.console_message("Printing the member variables:")
     G.print_members()
 
     print ""
