@@ -2,6 +2,7 @@
 
 
 import sys
+from collections import defaultdict
 
 try:
     import wx
@@ -50,6 +51,7 @@ import traceback
 import pytransit
 import pytransit.analysis
 import pytransit.export
+import pytransit.convert
 import pytransit.trash as trash
 import pytransit.transit_tools as transit_tools
 import pytransit.tnseq_tools as tnseq_tools
@@ -64,6 +66,7 @@ import pytransit.images as images
 method_wrap_width = 250
 methods = pytransit.analysis.methods
 export_methods = pytransit.export.methods
+convert_methods = pytransit.convert.methods
 normmethods = norm_tools.methods
 
 
@@ -113,21 +116,32 @@ class MainFrame ( wx.Frame ):
 
         bSizer4 = wx.BoxSizer( wx.VERTICAL )
 
-        # ANNOTATION
         orgSizer = wx.StaticBoxSizer( wx.StaticBox( self.mainWindow, wx.ID_ANY, u"Organism" ), wx.VERTICAL )
 
-        bSizer10 = wx.BoxSizer( wx.HORIZONTAL )
+        # ANNOTATION
+        annot_sizer = wx.BoxSizer( wx.HORIZONTAL )
+        label_annot = wx.StaticText( self.mainWindow, wx.ID_ANY, u"Annotation File:", wx.DefaultPosition, wx.DefaultSize, 0 )
+        annot_sizer.Add(label_annot,0,wx.ALIGN_CENTER_VERTICAL,0)
+        self.annotationFilePicker = wx.FilePickerCtrl(self.mainWindow, id=wx.ID_ANY, size=(400,30), wildcard=u"prot_table or GFF3 files (*.gff3;*.gff;*.prot_table;*.txt)|*.gff3;*.gff;*.prot_table;*.txt", message = "Select Annotation file (.prot_table or .gff3)", style=wx.FLP_DEFAULT_STYLE|wx.FLP_USE_TEXTCTRL|wx.FD_MULTIPLE)
+        self.annotationFilePicker.SetInitialDirectory(os.getcwd())
+        annot_sizer.Add(self.annotationFilePicker, proportion=1, flag=wx.EXPAND|wx.ALL, border=5)
 
-        self.m_staticText5 = wx.StaticText( self.mainWindow, wx.ID_ANY, u"Annotation File:", wx.DefaultPosition, wx.DefaultSize, 0 )
-        self.m_staticText5.Wrap( -1 )
-        bSizer10.Add( self.m_staticText5, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )
+        orgSizer.Add( annot_sizer, 1, wx.EXPAND, 5 )
+
+        # ANNOTATION
+
+        # bSizer10 = wx.BoxSizer( wx.HORIZONTAL )
+
+        # self.m_staticText5 = wx.StaticText( self.mainWindow, wx.ID_ANY, u"Annotation File:", wx.DefaultPosition, wx.DefaultSize, 0 )
+        # self.m_staticText5.Wrap( -1 )
+        # bSizer10.Add( self.m_staticText5, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )
 
 
-        self.annotationFilePicker = GenBitmapTextButton(self.mainWindow, 1, bmp, '[Click to add Annotation File (.prot_table or .gff3)]', size= wx.Size(500, -1))
+        # self.annotationFilePicker = GenBitmapTextButton(self.mainWindow, 1, bmp, '[Click to add Annotation File (.prot_table or .gff3)]', size= wx.Size(500, -1))
 
-        bSizer10.Add( self.annotationFilePicker, 1, wx.ALIGN_CENTER_VERTICAL, 5 )
+        # bSizer10.Add( self.annotationFilePicker, 1, wx.ALIGN_CENTER_VERTICAL, 5 )
 
-        orgSizer.Add( bSizer10, 1, wx.EXPAND, 5 )
+        # orgSizer.Add( bSizer10, 1, wx.EXPAND, 5 )
 
         bSizer4.Add( orgSizer, 0, wx.EXPAND, 5 )
 
@@ -430,8 +444,8 @@ class MainFrame ( wx.Frame ):
 
         self.convertMenuItem.Append( self.annotationConvertPTTToPT )
 
-        self.annotationConvertGFF3ToPT = wx.MenuItem( self.convertMenuItem, wx.ID_ANY, u"GFF3 to prot_table", wx.EmptyString, wx.ITEM_NORMAL )
-        self.convertMenuItem.Append( self.annotationConvertGFF3ToPT )
+        # self.annotationConvertGFF3ToPT = wx.MenuItem( self.convertMenuItem, wx.ID_ANY, u"GFF3 to prot_table", wx.EmptyString, wx.ITEM_NORMAL )
+        # self.convertMenuItem.Append( self.annotationConvertGFF3ToPT )
         self.fileMenuItem.AppendSubMenu( self.convertMenuItem, u"Convert" )
 
         self.fileExitMenuItem = wx.MenuItem( self.fileMenuItem, wx.ID_ANY, u"&Exit", wx.EmptyString, wx.ITEM_NORMAL )
@@ -483,7 +497,7 @@ class MainFrame ( wx.Frame ):
 
         # Connect Events
 
-        self.annotationFilePicker.Bind( wx.EVT_BUTTON, self.annotationFileFunc )
+        self.annotationFilePicker.Bind( wx.EVT_FILEPICKER_CHANGED, self.annotationFileFunc )
         self.ctrlRemoveButton.Bind( wx.EVT_BUTTON, self.ctrlRemoveFunc )
         self.ctrlView.Bind( wx.EVT_BUTTON, self.allViewFunc )
         self.ctrlScatter.Bind( wx.EVT_BUTTON, self.scatterFunc )
@@ -501,7 +515,7 @@ class MainFrame ( wx.Frame ):
         self.Bind( wx.EVT_MENU, self.annotationPT_to_PTT, id = self.annotationConvertPTToPTTMenu.GetId() )
         self.Bind( wx.EVT_MENU, self.annotationPT_to_GFF3, id = self.annotationConvertPTToGFF3Menu.GetId() )
         self.Bind( wx.EVT_MENU, self.annotationPTT_to_PT, id = self.annotationConvertPTTToPT.GetId() )
-        self.Bind( wx.EVT_MENU, self.annotationGFF3_to_PT, id = self.annotationConvertGFF3ToPT.GetId() )
+        # self.Bind( wx.EVT_MENU, self.annotationGFF3_to_PT, id = self.annotationConvertGFF3ToPT.GetId() )
         self.Bind( wx.EVT_MENU, self.Exit, id = self.fileExitMenuItem.GetId() )
         self.Bind( wx.EVT_MENU, self.scatterFunc, id = self.scatterMenuItem.GetId() )
         self.Bind( wx.EVT_MENU, self.allViewFunc, id = self.trackMenuItem.GetId() )
@@ -705,13 +719,25 @@ class TnSeekFrame(MainFrame):
             self.Bind( wx.EVT_MENU, partial(self.ExportSelectFunc,  export_methods[name].label),
                 tempMenuItem )
 
+        # Convert Menu Items
+        for name in convert_methods:
+            convert_methods[name].gui.defineMenuItem(self, convert_methods[name].label)
+            tempMenuItem = convert_methods[name].gui.menuitem
+            self.convertMenuItem.Append( tempMenuItem )
 
+            self.Bind( wx.EVT_MENU, partial(self.ConvertSelectFunc,  convert_methods[name].label),
+                tempMenuItem )
 
 
         # Method Panels
 
         methodChoiceChoices = [ "[Choose Method]"]
-        for name in methods:
+        methodorder = [("gumbel", 1), ("resampling", 2), ("hmm", 3)]
+        order = defaultdict(lambda: 100)
+        for k, v in methodorder:
+            order[k] = v
+
+        for name in sorted(methods.keys(), key=lambda x: order[x]):
             methods[name].gui.definePanel(self)
             #methods[name].gui.panel.BackgroundColour = (0, 200, 20)
             self.methodSizer.Add(methods[name].gui.panel, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL, 5 )
@@ -781,7 +807,6 @@ class TnSeekFrame(MainFrame):
 
             try:
                 self.annotation = os.path.join(os.path.dirname('/pacific/home/mdejesus/transit/src/transit.py'), "pytransit/genomes/H37Rv.prot_table")
-                self.annotationFilePicker.SetLabel(transit_tools.basename(self.annotation))
                 transit_tools.transit_message("Annotation File Selected: %s" % self.annotation)
             except Exception as e:
                 print "Error:", str(e)
@@ -1415,17 +1440,19 @@ along with TRANSIT.  If not, see <http://www.gnu.org/licenses/>.
             traceback.print_exc()
 
 #
-
     def annotationFileFunc(self, event):
+        self.annotation=event.GetPath()
 
-        wc = u"Known Annotation Formats (*.prot_table,*.gff3,*.gff)|*.prot_table;*.gff3;*.gff;|\nProt Table (*.prot_table)|*.prot_table;|\nGFF3 (*.gff,*.gff3)|*.gff;*.gff3;|\nAll files (*.*)|*.*"
-        self.annotation = self.OpenFile(DIR=self.workdir, FILE="", WC=wc)
-        if self.annotation:
-            self.annotationFilePicker.SetLabel(transit_tools.basename(self.annotation))
-            if self.verbose:
-                transit_tools.transit_message("Annotation File Selected: %s" % self.annotation)
-        else:
-            self.annotationFilePicker.SetLabel("[Click to add Annotation File (.prot_table or .gff3)]")
+    # def annotationFileFunc(self, event):
+
+    #     wc = u"Known Annotation Formats (*.prot_table,*.gff3,*.gff)|*.prot_table;*.gff3;*.gff;|\nProt Table (*.prot_table)|*.prot_table;|\nGFF3 (*.gff,*.gff3)|*.gff;*.gff3;|\nAll files (*.*)|*.*"
+    #     self.annotation = self.OpenFile(DIR=self.workdir, FILE="", WC=wc)
+    #     if self.annotation:
+    #         self.annotationFilePicker.SetLabel(transit_tools.basename(self.annotation))
+    #         if self.verbose:
+    #             transit_tools.transit_message("Annotation File Selected: %s" % self.annotation)
+    #     else:
+    #         self.annotationFilePicker.SetLabel("[Click to add Annotation File (.prot_table or .gff3)]")
 
 #
     def MethodSelectFunc(self, selected_name, test=""):
@@ -1504,6 +1531,21 @@ along with TRANSIT.  If not, see <http://www.gnu.org/licenses/>.
                     transit_tools.transit_message("Error: %s" % str(e))
                     traceback.print_exc()
 
+    def ConvertSelectFunc(self, selected_name, test=""):
+        annotationpath = self.annotation
+
+        for name in convert_methods:
+            if convert_methods[name].label == selected_name:
+                methodobj = convert_methods[name].method
+                try:
+                    M = methodobj.fromGUI(self)
+                    if M:
+                        thread = threading.Thread(target=M.Run())
+                        thread.setDaemon(True)
+                        thread.start()
+                except Exception as e:
+                    transit_tools.transit_message("Error: %s" % str(e))
+                    traceback.print_exc()
 #
 
     def displayFileFunc(self, event):
